# -*- coding: utf-8 -*-
# FOGLAMP_BEGIN
# See: https://foglamp-foglamp-documentation.readthedocs-hosted.com
# FOGLAMP_END

""" Plugin module which converts attributes into individual assets """

import os
import logging
import datetime
import filter_ingest
import traceback
import copy
from foglamp.common import logger

# local logger
_LOGGER = logger.setup(__name__, level=logging.WARN)


_DEFAULT_CONFIG = {
    'plugin': {        # mandatory  filter
        'description': 'filter that converts attribute into individual assets',
        'type': 'string',
        'default': 'kochafloc',
        'readonly': 'true'
    },
    'enable': {    # recommended filter
        'description': 'Enable filter plugin',
        'type': 'boolean',
        'default': 'false',
        'displayName': 'Enabled',
        'order': "1"
    },
    'prefix': {
        'description': 'Static prefix for AF Location Hint',
        'type': 'string',
        'default': '',
        'displayName': 'Prefix',
        'order': '2'
    }
}



def plugin_info():
    """ Returns information about the plugin.
    Args:
    Returns:
        dict: plugin information
    Raises:
    """
    _LOGGER.info("KochAFLoc - plugin_info called")
    return {
        'name': 'KochAFLoc',
        'version': '1.9.2',
        'mode': 'none',
        'type': 'filter',
        'interface': '1.0',
        'config': _DEFAULT_CONFIG
    }


def plugin_init(config, ingest_ref, callback):
    """ Initialise the plugin.
    Args:
        config: JSON configuration document for the plugin configuration category
    Returns:
        data: JSON object to be used in future calls to the plugin
    Raises:
    """

    _LOGGER.info("KochAFLoc - plugin_init called")
    try:
        _config = copy.deepcopy(config)
        _config['ingest_ref'] = ingest_ref
        _config['callback'] = callback
    except:
        _LOGGER.info("could not create configuration")
        raise
    return _config


def plugin_ingest(handle, data):
    """ plugin_ingest -- log data we receive """

    try:
        if type(data) == dict:
            data = [data]
        datasplit = []
        for entry in data:
            #_LOGGER.info("{}".format(entry))
            asset_prefix = entry['asset'].split('.')[0]
            hint = '{\\"AFLocation\\":\\"%s%s\\"}'
            hint = hint % (handle['prefix']['value'],asset_prefix)
            entry['readings']['OMFHint'] = hint
            #_LOGGER.info("{}".format(entry))
        filter_ingest.filter_ingest_callback(handle['callback'], handle['ingest_ref'], data)
    except Exception as ex:
        _LOGGER.error("KochAFLoc writer exception {}".format(traceback.format_exc()))
        raise


def plugin_reconfigure(handle, new_config):
    """ Reconfigures the plugin
    Args:
        handle: handle returned by the plugin initialisation call
        new_config: JSON object representing the new configuration category for the category
    Returns:
        new_handle: new handle to be used in the future calls
    """

    _LOGGER.info("Old config for  plugin {} \n new config {}".format(handle, new_config))
    plugin_shutdown(handle)
    # plugin_init
    new_handle = plugin_init(new_config, handle['ingest_ref'], handle['callback'])
    return new_handle


def plugin_shutdown(handle):
    """ Shut down the plugin.
    Args:
        handle: JSON configuration document for the plugin configuration category
    Returns:
        data: JSON object to be used in future calls to the plugin
    Raises:
    """
    _LOGGER.info("KochAFLoc Shutdown")

